platform

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsCygwin

func IsCygwin(fd uintptr) bool

IsCygwin returns true if the given file descriptor is a Cygwin/MSYS2 terminal. This function is only relevant on Windows and always returns false on other platforms.

func IsTerminal

func IsTerminal(fd uintptr) bool

IsTerminal returns true if the given file descriptor is a terminal. This function is implemented differently for each platform.

Types

This section is empty.

Jump to