Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsCygwin ¶
IsCygwin returns true if the given file descriptor is a Cygwin/MSYS2 terminal. This function is only relevant on Windows and always returns false on other platforms.
func IsTerminal ¶
IsTerminal returns true if the given file descriptor is a terminal. This function is implemented differently for each platform.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.